import {
  defineComponent,
  ref,
  reactive,
  onMounted,
  onBeforeUnmount,
  renderSlot,
} from 'vue';
import { formatTime } from '@/utils/index'
import { WEEK } from '@/constant/index'
import PublicCom from '../../components/PublicCom/index'
import { title, subtitle, moduleInfo } from '@/constant'
import dayjs from 'dayjs'
import './index.scss'
import TweenMax from 'gsap'

export default defineComponent({
  setup() {
    //#region 申明变量
    const login = ref<boolean>(true)
    // * 加载标识
    const loading = ref<boolean>(true)
    // * 时间内容
    const timeInfo = reactive({
      setInterval: 0,
      dateDay: '',
      dateYear: '',
      dateWeek: ''
    })
    //#endregion

    //#region 调用函数
    // 生命周期
    onMounted(() => {
      handleTime();
      tweenmax();
    });
    //组件实例被卸载之前调用
    onBeforeUnmount(() => {
      clearInterval(timeInfo.setInterval)
    });

    //todo 处理 loading 展示
    const cancelLoading = () => {
      setTimeout(() => {
        loading.value = false
      }, 500)
    }
    //todo 处理时间监听 1s执行一次
    const handleTime = () => {
      timeInfo.setInterval = setInterval(() => {
        const date = new Date()
        timeInfo.dateDay = formatTime(date, 'HH: mm: ss')
        timeInfo.dateYear = formatTime(date, 'yyyy-MM-dd')
        timeInfo.dateWeek = WEEK[date.getDay()]
        console.log(loading.value);
      }, 1000)
    }
    //todo 动画
    const tweenmax = () => {
      TweenMax.to('.dh-left', 2, { x: -1000, repeat: -1 });
      TweenMax.to('.dh-right', 2, { x: 1000, repeat: -1 });
    };

    //Login
    const LoginFunc = () => {
      login.value=false;
      cancelLoading();
    }
    //#endregion

    //#region 返回界面结构
    return () => {
      return (
        <dv-full-screen-container>
          <div class="box">
            {login.value ? <div>我是登录
              <button onClick={LoginFunc}>登录</button>
            </div> : (<div>
              {loading.value ? <dv-loading >Loading...</dv-loading> : (
              <div>
                {/* <!-- 标题 --> */}
                <div class="titel">
                  {/* 时间显示 */}
                  <dv-decoration-5 class='titel-zjdh' dur='4' />
                  <div class='titel-time' v-if='loading.value=false'>
                    <div>{timeInfo.dateYear} {timeInfo.dateDay} {timeInfo.dateWeek}</div>
                  </div>
                  <div class="titel-right-bg"></div>
                  <div class="titel-left-bg"></div>
                  <div class="titel-tow-bg"></div>
                  <div class="titel-first-bg"></div>
                  <div class="titel-line"></div>

                  <div class="titel-border-le"></div>
                  <div class="titel-border-re"></div>
                  {/* 动画组件 */}
                  <div class="dh-left"></div>
                  <div class="dh-right"></div>
                  <div>{title}</div>
                </div>
                {/* <!-- 下面部分 --> */}
                <div class="main-box">
                  {/* <!-- 左边 --> */}
                  <div class="main-left">
                    <PublicCom title='测试'>
                      {{
                        children: () => {
                          return (
                            <div>
                              <div id='bzt' style="width: 100%;height:400px;">

                              </div>
                            </div>
                          )
                        }
                      }}
                    </PublicCom>
                  </div>
                  {/* <!-- 中间 --> */}
                  <div class="main-center">
                  </div>
                  {/* <!-- 右边 --> */}
                  <div class="main-right">
                  </div>
                </div>
              </div>
            )}
            </div>)}
          </div>
        </dv-full-screen-container>
      );
    }
    //#endregion
  }
});

