import {
  defineComponent,
  ref,
  reactive,
  onMounted,
  onBeforeUnmount,
  renderSlot,
} from 'vue';
import Fxcx from '../../components/fxcx/index'
import { title, subtitle, moduleInfo } from '@/constant'
import * as echarts from 'echarts';
import dayjs from 'dayjs'
import Api from '../../api/test'
import './index.scss'
import TweenMax from 'gsap'

//定义类型/接口

interface resData {
  code: number,
  content: string
}

export default defineComponent({
  //启动时候
  setup() {
    /** 
    *
    *子组件实例
    *
    */
    const FxcxRef = ref<any>()
    // * 加载标识
    const tit = ref<string | null>('')
    //是否打开弹窗
    const isOpen = ref<boolean>(false);
    // * 加载标识
    const loading = ref<boolean>(true)
    // * 时间内容
    const timeInfo = reactive({
      setInterval: 0,
      dateDay: '',
      dateYear: '',
      dateWeek: ''
    })
    const apires = ref<string>('');

    // 生命周期
    onMounted(() => {
      InitMap()
      cancelLoading()
      handleTime()
      console.log(dayjs().format('YYYY-MM-DD HH:mm:ss'));
      TweenMax.to('.dh-left', 2, { x: -1000, repeat: -1 });
      TweenMax.to('.dh-right', 2, { x: 1000, repeat: -1 });
    })

    onBeforeUnmount(() => {
      clearInterval(timeInfo.setInterval)
    })

    // methods
    // todo 处理 loading 展示
    const cancelLoading = () => {
      setTimeout(() => {
        loading.value = false
      }, 500)
    }
    //给子组件传递方法
    const setChildFunc = () => {
      Api.test().then((res: resData) => {
        apires.value = res.content;
      })
    }
    //获取子组件方法
    const getChildFunc = () => {
      const { childFun1, childFun2 } = FxcxRef.value
      childFun1();
      childFun2();
    }

    // todo 处理时间监听
    const handleTime = () => {
      timeInfo.setInterval = setInterval(() => {
        const date = new Date()
        // timeInfo.dateDay = formatTime(date, 'HH: mm: ss')
        timeInfo.dateDay = dayjs().format('YYYY-MM-DD HH:mm:ss')
        // timeInfo.dateWeek = WEEK[date.getDay()]
      }, 1000)
    }
    type EChartsOption = echarts.EChartsOption;
    //例子，初始化饼状图
    const InitMap = () => {
      var chartDom = document.getElementById('bzt')!;
      var myChart = echarts.init(chartDom);
      var option: EChartsOption;
      option = {
        title: {
          text: '饼状图',
          subtext: '一月',
          left: 'center'
        },
        tooltip: {
          trigger: 'item'
        },
        legend: {
          orient: 'vertical',
          left: 'left'
        },
        series: [
          {
            name: 'Access From',
            type: 'pie',
            radius: '50%',
            data: [
              { value: 1048, name: '用电量' },
              { value: 735, name: '发电量' },
              { value: 580, name: '天回来' },
              { value: 484, name: '万事屋' },
              { value: 300, name: '哈哈哈' }
            ],
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            }
          }
        ]
      };
      option && myChart.setOption(option);
    }

    return () => {
      return (
        <div class="box">

          {isOpen ? <div></div> : ''}
          {/* <!-- 标题 --> */}
          <div class="titel">
            {/* 时间显示 */}
            <div class='titel-time'>{timeInfo.dateDay}</div>

            <div class="titel-right-bg"></div>
            <div class="titel-left-bg"></div>
            <div class="titel-tow-bg"></div>
            <div class="titel-first-bg"></div>
            <div class="titel-line"></div>

            <div id='titel-border' class="titel-border1"></div>
            <div class="titel-border2"></div>
            {/* 动画组件 */}
            <div class="dh-left"></div>
            <div class="dh-right"></div>
            <div>{title}</div>
          </div>
          {/* <!-- 下面部分 --> */}
          <div class="main-box">
            {/* <!-- 左边 --> */}
            <div class="main-left">
              <div onClick={getChildFunc}>点击我,我执行的子组件的方法</div>
              <Fxcx ref={FxcxRef} title="我是爸爸" nihao="你好" titelClick={setChildFunc} >
                {{

                  titel: () => {
                    return (
                      <>
                        我是子组件
                      </>
                    )
                  },
                  children: () => {
                    return (<div>
                      <div id='bzt' style="width: 100%;height:400px;">

                      </div>
                    </div>)
                  }
                }}
              </Fxcx>

              <div><dv-decoration-1 style="width:200px;height:50px;" />

              </div>
              <div><dv-border-box-4 style="width:100%;height:200px;text-align:center">
                <div class='dvborder-item'>{`接口获取数据展示:${apires.value}`}</div>
              </dv-border-box-4></div>
            </div>
            {/* <!-- 中间 --> */}
            <div class="main-center">
              <dv-border-box-8 reverse>

                <div>
                  <dv-scroll-board config={{
                    header: ['列1', '列2', '列3'],
                    data: [
                      ['行1列1', '行1列2', '行1列3'],
                      ['行2列1', '行2列2', '行2列3'],
                      ['行3列1', '行3列2', '行3列3'],
                      ['行4列1', '行4列2', '行4列3'],
                      ['行5列1', '行5列2', '行5列3'],
                      ['行6列1', '行6列2', '行6列3'],
                      ['行7列1', '行7列2', '行7列3'],
                      ['行8列1', '行8列2', '行8列3'],
                      ['行9列1', '行9列2', '行9列3'],
                      ['行10列1', '行10列2', '行10列3']
                    ]
                  }} style="width:500px;height:220px" />
                </div>
                <div>
                  <dv-scroll-ranking-board config={{
                    data: [
                      {
                        name: '周口',
                        value: 55
                      },
                      {
                        name: '南阳',
                        value: 120
                      },
                      {
                        name: '西峡',
                        value: 78
                      },
                      {
                        name: '驻马店',
                        value: 66
                      },
                      {
                        name: '新乡',
                        value: 80
                      },
                      {
                        name: '信阳',
                        value: 45
                      },
                      {
                        name: '漯河',
                        value: 29
                      }
                    ]
                  }} style="width:500px;height:300px" />
                </div>
              </dv-border-box-8>
            </div>
            {/* <!-- 右边 --> */}
            <div class="main-right">
              <dv-border-box-8 reverse>
                <div class='row'>
                  <dv-water-level-pond config={{ data: [66] }} style="width:150px;height:200px" />
                  <dv-percent-pond config={{ value: 66 }} style="width:200px;height:100px;" />
                </div>
                <dv-capsule-chart config={{
                  data: [
                    {
                      name: '南阳',
                      value: 167
                    },
                    {
                      name: '周口',
                      value: 67
                    },
                    {
                      name: '漯河',
                      value: 123
                    },
                    {
                      name: '郑州',
                      value: 55
                    },
                    {
                      name: '西峡',
                      value: 98
                    },
                  ],
                  unit: '单位'
                }} style="width:300px;height:200px" />
                {/* 表格 两行两列*/}
                <div class='row'>
                  <div class='col'>
                    <div>1</div>
                    <div>2</div>
                  </div>
                  <div class='col'>
                    <div>1</div>
                    <div>2</div>
                  </div>
                  <div class='col'>
                    <div>1</div>
                    <div>2</div>
                  </div>
                </div>
              </dv-border-box-8>
            </div>
          </div>
        </div>
      );
    }
  }

});

